@@ -1,7 +1,6 @@
 import astropy.units as u
 from ruamel.yaml import YAML
 from collections import namedtuple
-from .features import find_used_source_features
 import numpy as np
 from sklearn.base import is_classifier, is_regressor
 import logging
@@ -13,6 +12,8 @@ from sklearn import svm
 from sklearn import tree
 from sklearn import naive_bayes
 
+from .features import find_used_source_features
+
 
 sklearn_modules = {
     'ensemble': ensemble,
@@ -209,8 +210,8 @@ class DispConfig:
         self.features.sort()
 
         self.source_az_column = model_config.get('source_az_column', 'source_position_az')
-        self.source_zd_column = model_config.get('source_zd_column', None)
-        self.source_alt_column = model_config.get('source_alt_column', None)
+        self.source_zd_column = model_config.get('source_zd_column')
+        self.source_alt_column = model_config.get('source_alt_column')
         if (self.source_zd_column is None) is (self.source_alt_column is None):
             raise ValueError(
                     'Need to specify exactly one of'
@@ -218,13 +219,10 @@ class DispConfig:
                     'source_zd_column: {}, source_alt_column: {}'.format(
                         self.source_zd_column, self.source_alt_column)
                     )
-        self.source_az_unit = u.Unit(model_config.get('source_az_unit', 'deg'))
-        self.source_zd_unit = u.Unit(model_config.get('source_zd_unit', 'deg'))
-        self.source_alt_unit = u.Unit(model_config.get('source_alt_unit', 'deg'))
 
         self.pointing_az_column = model_config.get('pointing_az_column', 'pointing_position_az')
-        self.pointing_zd_column = model_config.get('pointing_zd_column', None)
-        self.pointing_alt_column = model_config.get('pointing_alt_column', None)
+        self.pointing_zd_column = model_config.get('pointing_zd_column')
+        self.pointing_alt_column = model_config.get('pointing_alt_column')
         if (self.pointing_zd_column is None) is (self.pointing_alt_column is None):
             raise ValueError(
                     'Need to specify exactly one of'
@@ -232,9 +230,11 @@ class DispConfig:
                     'pointing_zd_column: {}, pointing_alt_column: {}'.format(
                         self.pointing_zd_column, self.pointing_alt_column)
                     )
-        self.pointing_az_unit = u.Unit(model_config.get('pointing_zd_unit', 'deg'))
-        self.pointing_zd_unit = u.Unit(model_config.get('pointing_zd_unit', 'deg'))
-        self.pointing_alt_unit = u.Unit(model_config.get('pointing_alt_unit', 'deg'))
+
+        for name in ('source', 'pointing'):
+            for coord in ('alt', 'az', 'zd'):
+                col = f'{name}_{coord}_unit'
+                setattr(self, col, u.Unit(model_config.get(col, 'deg')))
 
         self.focal_length_column = model_config.get('focal_length_column', 'focal_length')
         self.focal_length_unit = u.Unit(model_config.get('focal_length', 'm'))
