@@ -42,17 +42,9 @@ def main(configuration_path, performance_path, data_path, disp_model_path, sign_
     log.info('Loading perfomance data')
     df = fact.io.read_data(performance_path, key=key)
 
-    columns = [
-        model_config.source_az_column,
-        model_config.source_zd_column,
-        model_config.pointing_az_column,
-        model_config.pointing_zd_column,
-        model_config.cog_y_column,
-        model_config.cog_x_column,
-        model_config.delta_column
-    ]
+    columns = model_config.columns_to_read_train
+
     if model_config.coordinate_transformation == 'CTA':
-        columns.append(model_config.focal_length_column)
         camera_unit = r'\mathrm{m}'
     else:
         camera_unit = r'\mathrm{mm}'
@@ -131,7 +123,9 @@ def main(configuration_path, performance_path, data_path, disp_model_path, sign_
     plot_true_delta_delta(df_data, model_config, ax)
 
     if config.true_energy_column in df.columns:
-        fig = plot_energy_dependent_disp_metrics(df, config.true_energy_column)
+        fig = plot_energy_dependent_disp_metrics(
+            df, config.true_energy_column, energy_unit=config.energy_unit
+        )
         figures.append(fig)
 
     if output is None:
